aboutsummaryrefslogtreecommitdiffstats
path: root/engine/items/tms.asm
diff options
context:
space:
mode:
Diffstat (limited to 'engine/items/tms.asm')
-rw-r--r--engine/items/tms.asm12
1 files changed, 6 insertions, 6 deletions
diff --git a/engine/items/tms.asm b/engine/items/tms.asm
index 40030675..06d60ad3 100644
--- a/engine/items/tms.asm
+++ b/engine/items/tms.asm
@@ -1,7 +1,7 @@
; tests if mon [wcf91] can learn move [wMoveNum]
CanLearnTM:
- ld a, [wcf91]
- ld [wd0b5], a
+ ld a, [wCurPartySpecies]
+ ld [wCurSpecies], a
call GetMonHeader
ld hl, wMonHLearnset
push hl
@@ -26,17 +26,17 @@ CanLearnTM:
ld c, 0
ret
; converts TM/HM number in wd11e into move number
; HMs start at 51
TMToMove:
- ld a, [wd11e]
+ ld a, [wTempTMHM]
dec a
ld hl, TechnicalMachines
ld b, $0
ld c, a
add hl, bc
ld a, [hl]
- ld [wd11e], a
+ ld [wTempTMHM], a
ret
INCLUDE "data/moves/tmhm_moves.asm"
@@ -1,7 +1,7 @@
-; tests if mon [wcf91] can learn move [wMoveNum]
+; tests if mon [wCurPartySpecies] can learn move [wMoveNum]
CanLearnTM:
@@ -26,17 +26,17 @@ CanLearnTM:
ld c, 0
ret
-; converts TM/HM number in wd11e into move number
+; converts TM/HM number in [wTempTMHM] into move number
; HMs start at 51
TMToMove: